#
# spec file for package xerces-c
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xerces-c
BuildRequires:  gcc-c++
BuildRequires:  libicu-devel
BuildRequires:  pkgconfig
Version:        3.1.1
Release:        22.3
Summary:        A Validating XML Parser
License:        Apache-2.0
Group:          Productivity/Publishing/XML
Url:            http://xerces.apache.org/xerces-c/
Source0:        %{name}-%{version}.tar.gz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM bnc920810 xerces-c-CVE-2015-0252.patch pwieczorkiewicz@suse.com -- Fix for mishandling certain kinds of malformed input documents
Patch1:         %{name}-CVE-2015-0252.patch
# PATCH-FIX-UPSTREAM bsc#966822 xerces-c-CVE-2016-0729.patch pwieczorkiewicz@suse.com -- Fix for XML Parser Crashes on Malformed Input
Patch2:         %{name}-CVE-2016-0729.patch
# PATCH-FIX-UPSTREAM bsc#979208
Patch3:         %{name}-CVE-2016-2099.patch
# PATCH-FIX-UPSTREAM bnc#985860 CVE-2016-4463
Patch4:         xerces-c-CVE-2016-4463-part1.patch
Patch5:         xerces-c-CVE-2016-4463-part2.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Xerces-C is a validating XML parser written in a portable subset of
C++. Xerces-C makes it easy to give your application the ability to
read and write XML data. A shared library is provided for parsing,
generating, manipulating, and validating XML documents. Xerces-C is
faithful to the XML 1.0 recommendation and associated standards ( DOM
1.0, DOM 2.0. SAX 1.0, SAX 2.0, Namespaces).

%package -n libxerces-c-3_1
Summary:        Shared libraries for Xerces-c - a validating XML parser
Group:          Productivity/Publishing/XML
Provides:       Xerces-c = %{version}
Obsoletes:      Xerces-c <= %{version}

%description -n libxerces-c-3_1
Xerces-C is a validating XML parser written in a portable subset of
C++. Xerces-C makes it easy to give your application the ability to
read and write XML data. A shared library is provided for parsing,
generating, manipulating, and validating XML documents. Xerces-C is
faithful to the XML 1.0 recommendation and associated standards ( DOM
1.0, DOM 2.0. SAX 1.0, SAX 2.0, Namespaces).

This package contains just the shared libraries.

%package -n libxerces-c-devel
Requires:       libxerces-c-3_1 = %{version}
Provides:       Xerces-c-devel = %{version}
Obsoletes:      Xerces-c-devel <= %{version}
Provides:       libXerces-c-devel = %{version}
Obsoletes:      libXerces-c-devel <= %{version}
Summary:        A validating XML parser - Development Files
Group:          Development/Libraries/C and C++

%description -n libxerces-c-devel
Xerces-C is a validating XML parser written in a portable subset of
C++. Xerces-C makes it easy to give your application the ability to
read and write XML data. A shared library is provided for parsing,
generating, manipulating, and validating XML documents.

This package includes files needed for development with Xerces-c

%prep
%setup -q -n xerces-c-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p0
%patch4 -p1
%patch5 -p1

%build
%configure \
%ifnarch x86_64
    --disable-sse2 \
%endif
    --disable-static
make %{?_smp_mflags}

%install
make DESTDIR=$RPM_BUILD_ROOT install
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la

%post -n libxerces-c-3_1 -p /sbin/ldconfig

%postun -n libxerces-c-3_1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc CREDITS KEYS LICENSE NOTICE README doc/*
%{_bindir}/*

%files -n libxerces-c-3_1
%defattr(-,root,root)
%{_libdir}/libxerces-c-3.1.so

%files -n libxerces-c-devel
%defattr(-,root,root)
%{_includedir}/xercesc
%{_libdir}/libxerces-c.so
%{_libdir}/pkgconfig/xerces-c.pc

%changelog
* Mon Jun 27 2016 tchvatal@suse.com
- Add patches for bnc#985860 CVE-2016-4463:
  * xerces-c-CVE-2016-4463-part1.patch
  * xerces-c-CVE-2016-4463-part2.patch
* Thu Jun 16 2016 pjanouch@suse.de
- added xerces-c-CVE-2016-2099.patch
  Exception handling mistake causing use after free
  (bsc#979208, CVE-2016-2099)
* Tue Mar 29 2016 pwieczorkiewicz@suse.com
- xerces-c-CVE-2016-0729.patch:
  Fix for mishandling certain kinds of malformed input documents,
  resulting in buffer overlows during processing and error reporting.
  The overflows can manifest as a segmentation fault or as memory
  corruption during a parse operation. (bsc#966822, CVE-2016-0729)
* Fri Mar  6 2015 pwieczorkiewicz@suse.com
- xerces-c-CVE-2015-0252.patch:
  Fix for mishandling certain kinds of malformed input documents,
  resulting in a segmentation fault during a parse operation
  (bnc#920810,CVE-2015-0252)
* Thu Dec 12 2013 zaitor@opensuse.org
- Add baselib.conf in order to build -32Bit.
* Sun Oct 20 2013 hrvoje.senjan@gmail.com
- Disable sse2 instructions on non x86_64 arches, bnc#846539
* Fri Apr 13 2012 behrisch@users.sourceforge.net
- updated to 3.1.1
  * Check that we have non-NULL host before trying to connect (XERCESC-1920).
  * Recover from the mismatching start/end even count which may happen when we continue parsing an invalid document (XERCESC-1919).
  * If the transcoder doesn't process any input, throw an exception (XERCESC-1916).
    * Delay the recursive expansion of includes until the document fragment has been placed in the final location (XERCESC-1918).
  * The code formatting a content model was skipping the cardinality indicators (*, +, ?) (XERCESC-1914).
  * Fix a few bugs and memory leaks in XInclude code.
  * Give proper name to 64-bit PDB file in static build (XERCESC-1907).
  * Spelling fixes (XERCESC-1911).
  * Don't include cpuid.h if we are using intrin.h (XERCESC-1912).
  * Fix socket leak.
  * Set scanner object on validation context. Needed during QName validation. Don't re-validate default/fixed values in preContentValidation when called from loadGrammar. This values are already validated in TraverseSchema.
  * Remove explicit setting of prefix for cloned elements and attributes since it is done properly by the create*() functions (XERCESC-1913).
  * Initializing unitialized variables in TranscodeToStr and TranscodeFromStr (#XERCESC-1858).
  * Fixed a bug when transcoding small strings using TranscodeToStr (XERCESC-1858).
* Sat Jan 28 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
- Restore missing pkgconfig provides
* Wed Oct  7 2009 prusnak@suse.cz
- fix provides and obsoletes [bnc#544957]
* Thu Aug 13 2009 prusnak@suse.cz
- fix CVE-2009-1885 (CVE-2009-1885.patch) [bnc#530708]
* Tue Mar 10 2009 prusnak@suse.cz
- updated to 3.0.1
  * More robust handling of leading/trailing whitespaces (XERCESC-1838).
  * Minor documentation updates, including a fix for XERCESC-1848.
  * Add --disable-rpath configure option.
  * Remove class name from method declaration (XERCESC-1850).
  * Fix a bug in the socket and winsock net accessors when a redirection
    response does not contain a "Location" header.
  * Make XMLMutex use the correct MemoryManager when it closes it's mutex.
  * Documentation fixes (XERCESC-1841).
  * Backport fixes for memory leaks.
  * Alberto Massari  Force Borland projects to use CRLF EOL.
  * The wrong constructor was called, causing a memory leak (XERCESC-1840).
  * Fix memory leak (XERCESC-1834).
  * Update URLs in source code to point to the new pages.
* Tue Mar 10 2009 prusnak@suse.cz
- updated to 3.0.0
  * changes too numerous to list
- removed obsoleted patch:
  * lib64.patch
  * optflags.patch
* Mon Aug 18 2008 prusnak@suse.cz
- add -DNDEBUG to opt_flags
* Sun Aug 17 2008 ro@suse.de
- disable parallel build for now, breaks
* Thu Aug 14 2008 prusnak@suse.cz
- cleaned spec file (and renamed libXerces-c-28 to libXerces-c28)
* Mon Apr  7 2008 zpetrova@suse.CZ
- update to version 2.8.0
  - this version should fix large number of bugs.
  - Exponential growth of memory block (from 16KB to 128KB)
    that are allocated by the DOM heap.
  - The NODE_CLONED notification is now sent to each node's user data
    handler when cloning the entire DOMDocument.
  - Allow whitespace-only nodes to be added as children of a DOMDocument.
  - When a node is cloned or imported the type information (PSVI)
    is also copied.
* Tue Dec 18 2007 zpetrova@suse.cz
- fixed Required field for libXerces-c-27
* Mon Aug  6 2007 mrueckert@suse.de
- fixed file section for the devel package
- %%post* scriptlets for ldconfig
* Mon Aug  6 2007 mrueckert@suse.de
- added provides/obsoletes for the package rename
* Mon Aug  6 2007 zpetrova@suse.cz
- branch/rename package according to Share library guidelines.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 zpetrova@suse.cz
- added -fno-strict-aliasing.
* Wed Jan 11 2006 zpetrova@suse.cz
- update to 2.7.0
* Fri Sep  9 2005 zpetrova@suse.cz
- endelementfix.patch - namespace bug (#114685)
* Tue Jan 11 2005 didge@suse.de
- update to 2.6.0
- build with icu libraries
- did some cleanup
* Thu Mar 18 2004 didge@suse.de
- fixed bug #36229 with patch, provided there
* Mon Feb 23 2004 didge@suse.de
- update to 2.5.0
* Sat Jan 17 2004 meissner@suse.de
- added missing include to fix gcc3.4 build.
* Sun Jan  4 2004 nashif@suse.de
- update to 2.4.0
* Tue Aug 26 2003 nashif@suse.de
- Reduced docs
* Sun Jul 27 2003 nashif@suse.de
- update to version 2.3.0
* Tue May 27 2003 nashif@suse.de
- Removed CVS files
* Fri May 16 2003 nashif@suse.de
- update to version 2.2.0
* Mon Jan 20 2003 nashif@suse.de
- update to version 2.1.0
* Fri May 17 2002 nashif@suse.de
- lib64 problems fixed: Now build on all architectures
* Wed May 15 2002 nashif@suse.de
- Java not needed for build
* Fri Apr  5 2002 nashif@suse.de
- Update to 1.70
* Tue Dec 11 2001 nashif@suse.de
-  Update to version 1.60
* Mon Oct 29 2001 nashif@suse.de
- Update to latest version: 1.5.2
- Among others, this release contains the following fixes and
  new features:
  - Schema support
  - DatatypeValidator support
  - XMLDeleterFor related functions and data are removed.
    Replace with XMLRegisterCleanup.
  - Various bug fixes related to runConfigure
  - Comment outside root element should also be reported.
  - Added U+0110 to XMLEBCDICTranscoder.cpp's "Unicode to IBM037"
    translation table.
  - Add "Base64::encode" for encoding binary data.
  - Performance: Use XMLBufBid instead of XMLBuffer directly for
    better performance.
* Mon Oct  1 2001 nashif@suse.de
- Created sub-package doc
* Fri Aug 31 2001 nashif@suse.de
- Update to version 1.5.1
- This release includes various bug fixes and Schema support
* Mon May  7 2001 mfabian@suse.de
- bzip2 sources
* Tue Feb 27 2001 rolf@suse.de
- initial package 1.4.0 with devel subpackage
